<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'woocommerce' ) ) {
    // Bail early if WooCommerce Plugin is not installed
    return;
}

if ( ! function_exists( 'catcheverest_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function catcheverest_woocommerce_setup() {
        add_theme_support( 'woocommerce' );

        global $catcheverest_options_settings;

        $options = $catcheverest_options_settings;

        if ( ! $options['disable_product_gallery_zoom'] ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        if ( ! $options['disable_product_gallery_lightbox'] ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        if ( ! $options['disable_product_gallery_slider'] ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //catcheverest_woocommerce_setup
add_action( 'after_setup_theme', 'catcheverest_woocommerce_setup' );


/**
 * Adding support for WooCommerce Plugin
 *
 * uses remove_action to remove the WooCommerce Wrapper and add_action to add Simple Catch Wrapper
 *
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if ( ! function_exists( 'catcheverest_woocommerce_start' ) ) :
function catcheverest_woocommerce_start() {
	echo '<div id="primary" class="content-area"><div id="content" class="site-content woocommerce" role="main">';
}
endif; //catcheverest_woocommerce_start
add_action('woocommerce_before_main_content', 'catcheverest_woocommerce_start', 15);

if ( ! function_exists( 'catcheverest_woocommerce_end' ) ) :
function catcheverest_woocommerce_end() {
	echo '</div></div>';
}
endif; //catcheverest_woocommerce_end
add_action('woocommerce_after_main_content', 'catcheverest_woocommerce_end', 15);


function catcheverest_woocommerce_options( $wp_customize ) {
	global $catcheverest_options_defaults;

    $defaults = $catcheverest_options_defaults;

    // WooCommerce Options
    $wp_customize->add_section( 'catcheverest_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'catch-everest-pro' ),
        'priority'    => 220,
        'panel'       => 'catcheverest_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'catch-everest-pro' ),
    ) );

    $wp_customize->add_setting( 'catcheverest_options[disable_product_gallery_zoom]', array(
        'default'           => $defaults['disable_product_gallery_zoom'],
        'sanitize_callback' => 'catcheverest_sanitize_checkbox',
        'type'				=> 'option',
    ) );

    $wp_customize->add_control(
        new CatchEverest_Customize_Checkbox(
            $wp_customize, 'catcheverest_options[disable_product_gallery_zoom]',
            array(
                'label'     => esc_html__( 'Check to disable Product Gallery Zoom', 'catch-everest-pro' ),
                'section'   => 'catcheverest_woocommerce_options',
            )
        )
    );

    $wp_customize->add_setting( 'catcheverest_options[disable_product_gallery_lightbox]', array(
        'default'           => $defaults['disable_product_gallery_lightbox'],
        'sanitize_callback' => 'catcheverest_sanitize_checkbox',
        'type'				=> 'option',
    ) );

    $wp_customize->add_control(
        new CatchEverest_Customize_Checkbox(
            $wp_customize, 'catcheverest_options[disable_product_gallery_lightbox]',
            array(
                'label'     => esc_html__( 'Check to disable Product Gallery Lightbox', 'catch-everest-pro' ),
                'section'   => 'catcheverest_woocommerce_options',
            )
        )
    );

    $wp_customize->add_setting( 'catcheverest_options[disable_product_gallery_slider]', array(
        'default'           => $defaults['disable_product_gallery_slider'],
        'sanitize_callback' => 'catcheverest_sanitize_checkbox',
        'type'				=> 'option',
    ) );

    $wp_customize->add_control(
        new CatchEverest_Customize_Checkbox(
            $wp_customize, 'catcheverest_options[disable_product_gallery_slider]',
            array(
                'label'     => esc_html__( 'Check to disable Product Gallery Slider', 'catch-everest-pro' ),
                'section'   => 'catcheverest_woocommerce_options',
            )
        )
    );
}
add_action( 'customize_register', 'catcheverest_woocommerce_options' );